@@ -13,10 +13,14 @@ class FileExtension:
     Attributes:
         extension (str):
         description (str):
+        is_for_projects (bool):
+        is_for_locations (bool):
     """
 
     extension: str
     description: str
+    is_for_projects: bool
+    is_for_locations: bool
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -24,12 +28,18 @@ class FileExtension:
 
         description = self.description
 
+        is_for_projects = self.is_for_projects
+
+        is_for_locations = self.is_for_locations
+
         field_dict: dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
                 "extension": extension,
                 "description": description,
+                "is_for_projects": is_for_projects,
+                "is_for_locations": is_for_locations,
             }
         )
 
@@ -42,9 +52,15 @@ class FileExtension:
 
         description = d.pop("description")
 
+        is_for_projects = d.pop("is_for_projects")
+
+        is_for_locations = d.pop("is_for_locations")
+
         file_extension = cls(
             extension=extension,
             description=description,
+            is_for_projects=is_for_projects,
+            is_for_locations=is_for_locations,
         )
 
         file_extension.additional_properties = d
